/*************************************************************************
 *
 *    Used with ICCARM and AARM.
 *
 *    (c) Copyright IAR Systems 2008
 *
 *    File name   : main.c
 *    Description : Define main module
 *
 *    History :
 *    1. Date        : 3, September 2008
 *       Author      : Stanimir Bonev
 *       Description : Create
 *
 *   This example project shows how to use the IAR Embedded Workbench
 *  for ARM to develop code for the IAR-STM32F107VC-SK board. It implements USB
 *  HID mouse. The any button will resume USB if device is suspended.
 *   The joystick control up, down, left, right and left mouse button, USER
 *  is the left mouse button too and WKUP is the right mouse button.
 *  Controls:
 *   Joystick    - left, right, up, down movement, center left button
 *   USER        - right button
 *   WKUP        - left button
 *
 *  Jumpers:
 *   PWR_SEL   - depending of power source
 *   VBUS      - O (OTG)
 *   USB_D-    - O (OTG)
 *   USB_D+    - O (OTG)
 *   JTAG_SEL  - open (on board j-link)
 *   B0_1/B0_0 - B0_0
 *   B1_1/B1_0 - B1_0
 *
 *    $Revision: #5 $
 **************************************************************************/

#include "includes.h"
#include "LED_Test.h"
#include "extcon_test.h"
#include "BattConTest.h"
#include "usb_otg_pintest.h"

#define LOOP_DLY_100US  450
#define MOUSE_DELTA     4

void HID_Mouse_test_NonBlocking(void);

Int32U CriticalSecCntr;
volatile Boolean SysTickFl;

/*************************************************************************
 * Function Name: TickHandler
 * Parameters: void
 * Return: void
 *
 * Description:
 *		
 *************************************************************************/
void TickHandler(void)
{
  SysTickFl = TRUE;
}

/*************************************************************************
 * Function Name: RTC_IRQ_PeriodicHandler
 * Parameters: void
 * Return: void
 *
 * Description: handles interrupts from Real Time Clock
 *		
 *************************************************************************/
void RTC_IRQ_PeriodicHandler(void)
{
	static int state = 0;

	RTC_ClearITPendingBit(RTC_IT_SEC);
	
	if(state++ & 0x01)
		GPIOC->BSRR = GPIO_Pin_7;
	else
		GPIOC->BRR = GPIO_Pin_7;
	
//	LED_Toggle(GPIO_Pin_7);
}

/*************************************************************************
 * Function Name: Dly100us
 * Parameters: Int32U Dly
 *
 * Return: none
 *
 * Description: Delay Dly * 100us
 *
 *************************************************************************/
void Dly100us(void *arg)
{
Int32U Dly = (Int32U)arg;
  while(Dly--)
  {
    for(volatile int i = LOOP_DLY_100US; i; i--);
  }
}

/*************************************************************************
 * Function Name: main
 * Parameters: none
 *
 * Return: none
 *
 * Description: main
 *
 *************************************************************************/
void main(void)
{
	ENTR_CRT_SECTION();
	/* Setup STM32 system (clock, PLL and Flash configuration) */
	SystemInit();
	
	/* Set the Vector Table base location at 0x08000000 */
	NVIC_SetVectorTable(NVIC_VectTab_FLASH, 0x0);
	NVIC_PriorityGroupConfig(NVIC_PriorityGroup_4);
	
	// SysTick end of count event each 0.02s with input clock equal to 9MHz (HCLK/8, default)
	SysTick_Config(180000); // (set to 90000 for 0.01s)
	SysTick_CLKSourceConfig(SysTick_CLKSource_HCLK_Div8);
	
	// Initialize LED test
	LED_Initialize();
	usbOtgPinTestIni();
			
	EXT_CRT_SECTION();
	
	// HID USB
	HidInit();

	
	// Soft connection enable
	USB_ConnectRes(TRUE);

	while(1) {
		HID_Mouse_test_NonBlocking();
		LED_test_NonBlocking();
	}
	

}

void HID_Mouse_test_NonBlocking(void)
{
#define MOVE_COUNT 40

	static Int8S X = 0, Y = 0;
	static Int8S Buttons = 0, ButtonsHold = 0;
	static int moveState = 0;
	static int moveCount = MOVE_COUNT;

    if (SysTickFl)
    {
      SysTickFl = FALSE;
	
	 if(UsbCoreReq(UsbCoreReqDevState) == UsbDevStatusConfigured)
      {	
	      switch(moveState) {
	      case 0:
		      if(moveCount--) {
			      X += MOUSE_DELTA;
			      Y -= MOUSE_DELTA;
		      }
		      else {
			      moveState = 1;
			      moveCount = MOVE_COUNT;
		      }
		      break;
	      case 1:
		      if(moveCount--) {
			      X += MOUSE_DELTA;
			      Y += MOUSE_DELTA;
		      }
		      else {
			      moveState = 2;
			      moveCount = MOVE_COUNT;
		      }
		      break;
	      case 2:
		      if(moveCount--) {
			      X -= MOUSE_DELTA;
			      Y += MOUSE_DELTA;
		      }
		      else {
			      moveState = 3;
			      moveCount = MOVE_COUNT;
		      }
		      break;
	      case 3:
		      if(moveCount--) {
			      X -= MOUSE_DELTA;
			      Y -= MOUSE_DELTA;
		      }
		      else {
			      moveState = 0;
			      moveCount = MOVE_COUNT;
		      }
		      break;
	      default:
		      moveState = 0;
		      moveCount = MOVE_COUNT;
		      break;
	      }

        if(Y || X  || Buttons || (ButtonsHold ^ Buttons))
        {
          // Send report
          HidMouseSendReport(X,Y,Buttons);
          ButtonsHold = Buttons;
          Y = X = Buttons = 0;
        }
      }
    }


}




